@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2007-2021 The HyperSpy developers
+# Copyright 2007-2022 The HyperSpy developers
 #
 # This file is part of HyperSpy.
 #
-#  HyperSpy is free software: you can redistribute it and/or modify
+# HyperSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-#  HyperSpy is distributed in the hope that it will be useful,
+# HyperSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with HyperSpy. If not, see <http://www.gnu.org/licenses/>.
+# along with HyperSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 import math
 from packaging.version import Version
@@ -62,8 +62,8 @@ class ImagePlot(BlittedFigure):
 
     """ % PLOT2D_DOCSTRING
 
-    def __init__(self, title=""):
-        super(ImagePlot, self).__init__()
+    def __init__(self, title="", **kwargs):
+        super().__init__()
         self.data_function = None
         self.data_function_kwargs = {}
 
@@ -201,7 +201,8 @@ class ImagePlot(BlittedFigure):
         xaxis = self.xaxis
         yaxis = self.yaxis
 
-        if ((xaxis.units == yaxis.units) and
+        if (xaxis.is_uniform and yaxis.is_uniform and
+                (xaxis.units == yaxis.units) and
                 (abs(xaxis.scale) == abs(yaxis.scale))):
             self._auto_scalebar = True
             self._auto_axes_ticks = False
@@ -220,10 +221,17 @@ class ImagePlot(BlittedFigure):
             self._ylabel += ' ({})'.format(yaxis.units)
 
         # Calibrate the axes of the navigator image
-        self._extent = [xaxis.axis[0] - xaxis.scale / 2.,
-                        xaxis.axis[-1] + xaxis.scale / 2.,
-                        yaxis.axis[-1] + yaxis.scale / 2.,
-                        yaxis.axis[0] - yaxis.scale / 2.]
+        if xaxis.is_uniform and yaxis.is_uniform:
+            xaxis_half_px = xaxis.scale / 2.
+            yaxis_half_px = yaxis.scale / 2.
+        else:
+            xaxis_half_px = 0
+            yaxis_half_px = 0
+        # Calibrate the axes of the navigator image
+        self._extent = [xaxis.axis[0] - xaxis_half_px,
+                        xaxis.axis[-1] + xaxis_half_px,
+                        yaxis.axis[-1] + yaxis_half_px,
+                        yaxis.axis[0] - yaxis_half_px]
         self._calculate_aspect()
         if self.saturated_pixels is not None:
             from hyperspy.exceptions import VisibleDeprecationWarning
@@ -249,7 +257,10 @@ class ImagePlot(BlittedFigure):
                 factor = min_asp ** -1 * xaxis.size / yaxis.size
                 self._auto_scalebar = False
                 self._auto_axes_ticks = True
-        self._aspect = np.abs(factor * xaxis.scale / yaxis.scale)
+        if xaxis.is_uniform and yaxis.is_uniform:
+            self._aspect = abs(factor * xaxis.scale / yaxis.scale)
+        else:
+            self._aspect = 1.0
 
     def _calculate_vmin_max(self, data, auto_contrast=False,
                             vmin=None, vmax=None):
@@ -371,7 +382,7 @@ class ImagePlot(BlittedFigure):
                 pass
 
         self.connect()
-        self.figure.canvas.draw()
+        self.render_figure()
 
     def _add_colorbar(self):
         # Bug extend='min' or extend='both' and power law norm
@@ -556,13 +567,9 @@ class ImagePlot(BlittedFigure):
                 )
             else:
                 ims[0].changed()
-            if self.figure.canvas.supports_blit:
-                self._update_animated()
-            else:
-                self.figure.canvas.draw_idle()
+            self.render_figure()
         else:  # no signal have been drawn yet
-            new_args = {'interpolation': 'nearest',
-                        'extent': self._extent,
+            new_args = {'extent': self._extent,
                         'aspect': self._aspect,
                         'animated': self.figure.canvas.supports_blit,
                         }
@@ -573,7 +580,6 @@ class ImagePlot(BlittedFigure):
                     new_args['norm'] = norm
             new_args.update(kwargs)
             self.ax.imshow(data, **new_args)
-            self.figure.canvas.draw_idle()
 
         if self.axes_ticks == 'off':
             self.ax.set_axis_off()
@@ -601,8 +607,10 @@ class ImagePlot(BlittedFigure):
         """ % (DISPLAY_DT, TOOLKIT_DT)
 
     def connect(self):
-        self.figure.canvas.mpl_connect('key_press_event',
-                                        self.on_key_press)
+        # in case the figure is not displayed
+        if self.figure is not None:
+            self.figure.canvas.mpl_connect('key_press_event',
+                                            self.on_key_press)
         if self.axes_manager:
             if self.update not in self.axes_manager.events.indices_changed.connected:
                 self.axes_manager.events.indices_changed.connect(self.update, [])
